@@ -3,29 +3,28 @@
 
     Copyright (c) 1999 - 2002 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QtXml/qdom.h>
-#include <QImage>
 #include <QToolTip>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QFontInfo>
 #include <QResizeEvent>
 
 
@@ -209,7 +208,7 @@ FancyPlotter::FancyPlotter( QWidget* parent,
     mPlotter->installEventFilter( this );
 
     setPlotterWidget( mPlotter );
-    connect(mPlotter, SIGNAL(axisScaleChanged()), this, SLOT(plotterAxisScaleChanged()));
+    connect(mPlotter, &KSignalPlotter::axisScaleChanged, this, &FancyPlotter::plotterAxisScaleChanged);
     QDomElement emptyElement;
     restoreSettings(emptyElement);
 }
@@ -289,9 +288,9 @@ void FancyPlotter::configureSettings()
     mSettingsDialog->setSensors( list );
     mSettingsDialog->setHasIntegerRange( hasIntegerRange );
 
-    connect( mSettingsDialog, SIGNAL(applyClicked()), this, SLOT(applySettings()) );
-    connect( mSettingsDialog, SIGNAL(okClicked()), this, SLOT(applySettings()) );
-    connect( mSettingsDialog, SIGNAL(finished(int)), this, SLOT(settingsFinished()) );
+    connect(mSettingsDialog, &FancyPlotterSettings::applyClicked, this, &FancyPlotter::applySettings);
+    connect(mSettingsDialog, &FancyPlotterSettings::okClicked, this, &FancyPlotter::applySettings);
+    connect(mSettingsDialog, &FancyPlotterSettings::finished, this, &FancyPlotter::settingsFinished);
 
     mSettingsDialog->show();
 }
@@ -515,7 +514,7 @@ void FancyPlotter::setTooltip()
             description = sensor->name();
 
         if(sensor->isOk()) {
-            lastValue = KGlobal::locale()->formatNumber( sensor->lastValue, (sensor->isInteger)?0:-1 );
+            lastValue = KLocale::global()->formatNumber( sensor->lastValue, (sensor->isInteger)?0:-1 );
             if (sensor->unit() == "%")
                 lastValue = i18nc("units", "%1%", lastValue);
             else if( !sensor->unit().isEmpty() )
@@ -586,7 +585,7 @@ void FancyPlotter::sendDataToPlotter( )
                         lastValue = mPlotter->lastValueAsString(beamId, precision);
                     } else {
                         precision = (sensor->isInteger)?0:-1;
-                        lastValue = KGlobal::locale()->formatNumber( mPlotter->lastValue(beamId), precision );
+                        lastValue = KLocale::global()->formatNumber( mPlotter->lastValue(beamId), precision );
                         if (sensor->unit() == "%")
                             lastValue = i18nc("units", "%1%", lastValue);
                         else if( !sensor->unit().isEmpty() )  {
@@ -618,7 +617,7 @@ void FancyPlotter::timerTick() //virtual
 void FancyPlotter::plotterAxisScaleChanged()
 {
     //Prevent this being called recursively
-    disconnect(mPlotter, SIGNAL(axisScaleChanged()), this, SLOT(plotterAxisScaleChanged()));
+    disconnect(mPlotter, &KSignalPlotter::axisScaleChanged, this, &FancyPlotter::plotterAxisScaleChanged);
     KLocalizedString unit;
     double value = mPlotter->currentMaximumRangeValue();
     if(mUnit  == "KiB") {
@@ -666,7 +665,7 @@ void FancyPlotter::plotterAxisScaleChanged()
     }
     mPlotter->setUnit(unit);
     //reconnect
-    connect(mPlotter, SIGNAL(axisScaleChanged()), this, SLOT(plotterAxisScaleChanged()));
+    connect(mPlotter, &KSignalPlotter::axisScaleChanged, this, &FancyPlotter::plotterAxisScaleChanged);
 }
 void FancyPlotter::answerReceived( int id, const QList<QByteArray> &answerlist )
 {
@@ -941,4 +940,4 @@ QColor FPSensorProperties::color() const
 }
 
 
-#include "FancyPlotter.moc"
+
